@@ -117,6 +117,14 @@ gnome_print_config_get_node (GnomePrintConfig *config)
 	return config->node;
 }
 
+/**
+ * gnome_print_config_default
+ *
+ * Creates a #GnomePrintConfig object with the default printer and settings.
+ *
+ * Returns: A pointer to a #GnomePrintConfig object with the default settings
+ *
+ **/
 GnomePrintConfig *
 gnome_print_config_default (void)
 {
@@ -128,6 +136,15 @@ gnome_print_config_default (void)
 	return config;
 }
 
+/**
+ * gnome_print_config_ref
+ * @config: The #GnomePrintConfig object to have its reference count increased
+ *
+ * Increase the reference count on the #GnomePrintConfig object by one.
+ *
+ * Returns: A pointer to the #GnomePrintConfig object or %NULL on failure
+ *
+ **/
 GnomePrintConfig *
 gnome_print_config_ref (GnomePrintConfig *config)
 {
@@ -139,6 +156,15 @@ gnome_print_config_ref (GnomePrintConfig *config)
 	return config;
 }
 
+/**
+ * gnome_print_config_unref
+ * @config: The #GnomePrintConfig object to have its reference count decreased
+ *
+ * Decrease the reference count on the #GnomePrintConfig object by one.
+ *
+ * Returns: A pointer to the #GnomePrintConfig object or %NULL on failure.
+ *
+ **/
 GnomePrintConfig *
 gnome_print_config_unref (GnomePrintConfig *config)
 {
@@ -150,6 +176,17 @@ gnome_print_config_unref (GnomePrintConfig *config)
 	return NULL;
 }
 
+/**
+ * gnome_print_config_dup
+ * @config: The config to be copied
+ *
+ * Does a deep copy of the config @config.  You should unref the returned 
+ * #GnomePrintConfig using #gnome_print_config_unref when you are finished
+ * using it.
+ *
+ * Returns: A copy of config
+ *
+ **/
 GnomePrintConfig *
 gnome_print_config_dup (GnomePrintConfig *old_config)
 {
@@ -197,6 +234,17 @@ gnome_print_config_keys_compat (const gchar *key)
 	return g_strdup (key);
 }
 
+/**
+ * gnome_print_config_get
+ * @config: Pointer to a #GnomePrintConfig object
+ * @key: String containing the path of key whose value is to be obtained
+ *
+ * Gets the value of string @key from the #GnomePrintConfig object.  The returned string
+ * should be freed with #g_free when you are finished with it.
+ *
+ * Returns: The value of the key, %NULL indicates failure.
+ *
+ **/
 guchar *
 gnome_print_config_get (GnomePrintConfig *config, const guchar *key)
 {
@@ -215,6 +263,17 @@ gnome_print_config_get (GnomePrintConfig *config, const guchar *key)
 	return val;
 }
 
+/**
+ * gnome_print_config_set
+ * @config: Pointer to a #GnomePrintConfig object
+ * @key: String containing the path of key whose value is to be set
+ * @value: String containing the value to set
+ *
+ * Sets the value of string @key in the #GnomePrintConfig object to value @value.
+ *
+ * Returns: %TRUE on success, %FALSE on failure
+ *
+ **/
 gboolean
 gnome_print_config_set (GnomePrintConfig *config, const guchar *key, const guchar *value)
 {
@@ -230,6 +289,19 @@ gnome_print_config_set (GnomePrintConfig *config, const guchar *key, const gucha
 	return result;
 }
 
+/**
+ * gnome_print_config_get_boolean
+ * @config: Pointer to a #GnomePrintConfig object
+ * @key: String containing the path of key whose value is to be obtained
+ * @val: Pointer to a boolean variable to store the value in.  Should initially be %NULL
+ *
+ * Gets the value of key @key from the #GnomePrintConfig object.  Converts values such
+ * as "true", "y", "yes", and their opposites, to their boolean equivalent.  The
+ * boolean value will be stored in the variable @val.
+ *
+ * Returns: #TRUE if a value was retrieved, #FALSE on failure
+ *
+ **/
 gboolean
 gnome_print_config_get_boolean (GnomePrintConfig *config, const guchar *key, gboolean *val)
 {
@@ -258,6 +330,19 @@ gnome_print_config_get_boolean (GnomePrintConfig *config, const guchar *key, gbo
 	return FALSE;
 }
 
+/**
+ * gnome_print_config_get_int
+ * @config: Pointer to a #GnomePrintConfig object
+ * @key: String containing the path of key whose value is to be obtained
+ * @val: Pointer to a integer variable to store the value in.  Should initially be %NULL
+ *
+ * Gets the value of key @key from the #GnomePrintConfig object.  Converts values
+ * to their integer equivalent.  The integer value will be stored in the variable 
+ * @val.
+ *
+ * Returns: #TRUE if a value was retrieved, #FALSE on failure
+ *
+ **/
 gboolean
 gnome_print_config_get_int (GnomePrintConfig *config, const guchar *key, gint *val)
 {
@@ -278,6 +363,19 @@ gnome_print_config_get_int (GnomePrintConfig *config, const guchar *key, gint *v
 	return TRUE;
 }
 
+/**
+ * gnome_print_config_get_double
+ * @config: Pointer to a #GnomePrintConfig object
+ * @key: String containing the path of key whose value is to be obtained
+ * @val: Pointer to a double variable to store the value in.  Should initially be %NULL
+ *
+ * Gets the value of key @key from the #GnomePrintConfig object.  Converts values
+ * to their double equivalent.  The double value will be stored in the variable 
+ * @val. 
+ *
+ * Returns: #TRUE if a value was retrieved, #FALSE on failure
+ *
+ **/
 gboolean
 gnome_print_config_get_double (GnomePrintConfig *config, const guchar *key, gdouble *val)
 {
@@ -304,6 +402,21 @@ gnome_print_config_get_double (GnomePrintConfig *config, const guchar *key, gdou
 	return result;
 }
 
+/**
+ * gnome_print_config_get_length
+ * @config: Pointer to a #GnomePrintConfig object
+ * @key: String containing the path of key whose value is to be obtained
+ * @val: Pointer to a double variable to store the value in.  Should initially be %NULL
+ * @unit: Pointer to an already allocated #GnomePrintUnit struct
+ *
+ * Gets the value of key @key from the #GnomePrintConfig object.  Converts values
+ * to their double equivalent.  The double value will be stored in the variable 
+ * @val and the units will be stored in @unit.  You should allocate the storage 
+ * for @unit before calling this function.
+ *
+ * Returns: #TRUE if a value was retrieved, #FALSE on failure
+ *
+ **/
 gboolean
 gnome_print_config_get_length (GnomePrintConfig *config, const guchar *key, gdouble *val, const GnomePrintUnit **unit)
 {
@@ -346,6 +459,17 @@ gnome_print_config_get_length (GnomePrintConfig *config, const guchar *key, gdou
 
 }
 
+/**
+ * gnome_print_config_set_boolean
+ * @config: Pointer to a #GnomePrintConfig object
+ * @key: String containing the path of key whose value is to be set
+ * @val: Boolean containing the value to set
+ *
+ * Set a @boolean value in the #GnomePrintConfig object.
+ *
+ * Returns: %TRUE on success, %FALSE on failure
+ *
+ **/
 gboolean
 gnome_print_config_set_boolean (GnomePrintConfig *config, const guchar *key, gboolean val)
 {
@@ -356,6 +480,17 @@ gnome_print_config_set_boolean (GnomePrintConfig *config, const guchar *key, gbo
 	return gnome_print_config_set (config, key, (val) ? "true" : "false");
 }
 
+/**
+ * gnome_print_config_set_int
+ * @config: Pointer to a #GnomePrintConfig object
+ * @key: String containing the path of key whose value is to be set
+ * @val: Integer containing the value to set
+ *
+ * Set an @integer value in the #GnomePrintConfig object.
+ *
+ * Returns: %TRUE on success, %FALSE on failure
+ *
+ **/
 gboolean
 gnome_print_config_set_int (GnomePrintConfig *config, const guchar *key, gint val)
 {
@@ -370,6 +505,17 @@ gnome_print_config_set_int (GnomePrintConfig *config, const guchar *key, gint va
 	return gnome_print_config_set (config, key, c);
 }
 
+/**
+ * gnome_print_config_set_double
+ * @config: Pointer to a #GnomePrintConfig object
+ * @key: String containing the path of key whose value is to be set
+ * @val: Double containing the value to set
+ *
+ * Set a @double value in the #GnomePrintConfig object.
+ *
+ * Returns: %TRUE on success, %FALSE on failure
+ *
+ **/
 gboolean
 gnome_print_config_set_double (GnomePrintConfig *config, const guchar *key, gdouble val)
 {
@@ -384,6 +530,19 @@ gnome_print_config_set_double (GnomePrintConfig *config, const guchar *key, gdou
 	return gnome_print_config_set (config, key, c);
 }
 
+/**
+ * gnome_print_config_set_length
+ * @config: Pointer to a #GnomePrintConfig object
+ * @key: String containing the path of key whose value is to be set
+ * @val: Double containing the value to set
+ * @unit: Units to use when setting value
+ *
+ * Sets a double value and the units it is using.  This should be used in 
+ * conjunction with #gnome_print_config_get_length.
+ *
+ * Returns: %TRUE on success, %FALSE on failure
+ *
+ **/
 gboolean
 gnome_print_config_set_length (GnomePrintConfig *config, const guchar *key, gdouble val, const GnomePrintUnit *unit)
 {
@@ -398,6 +557,11 @@ gnome_print_config_set_length (GnomePrintConfig *config, const guchar *key, gdou
 
 	g_ascii_dtostr (c, sizeof (c), val);
 	c_abbr = g_strconcat (c, unit->abbr, NULL);
+
+#if 0
+	g_warning ("gnome_print_config_set_length %s %s", key, unit->abbr);
+#endif
+
 	result = gnome_print_config_set (config, key, c_abbr);
 	g_free (c_abbr);
 
@@ -428,6 +592,14 @@ gnome_print_config_from_string (const gchar *str,
 	return config;
 }
 
+/**
+ * gnome_print_config_dump
+ * @gpc: The #GnomePrintConfig to output
+ *
+ * Print out the tree structure representing the GnomePrintConfig.  Output
+ * is to %STDOUT and is limited to a depth of 20.
+ *
+ **/
 void
 gnome_print_config_dump (GnomePrintConfig *config)
 {
